/*******************************************************************************
* Copyright (c) 2013 "Filippo Scognamiglio"
* https://github.com/Swordifish90/cool-old-term
*
* This file is part of cool-old-term.
*
* cool-old-term is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*******************************************************************************/

import QtQuick 2.1
import QtQuick.Controls 1.0
import QtQuick.Window 2.1
import QtQuick.Layouts 1.0
import QtQuick.Dialogs 1.1

ApplicationWindow {
    id: settings_window
    title: qsTr("Settings")
    width: 640
    height: 460

    modality: Qt.ApplicationModal

    TabView{
        anchors.fill: parent
        anchors.margins: 10
        Tab{
            title: qsTr("Appearance")
            anchors.fill: parent
            anchors.margins: 15
            GridLayout{
                anchors.fill: parent
                columns: 2
                GroupBox{
                    anchors.left: parent.left
                    anchors.right: parent.right
                    Layout.columnSpan: 2
                    title: qsTr("Profile")
                    ComboBox{
                        anchors.fill: parent
                        model: shadersettings.profiles_list
                        onCurrentIndexChanged: shadersettings.profiles_index = currentIndex
                        currentIndex: shadersettings.profiles_index
                    }
                }

                GroupBox{
                    id: fontbox
                    title: qsTr("Font")
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    GridLayout{
                        anchors.fill: parent
                        columns: 2
                        Text{text: qsTr("Font style:")}
                        ComboBox{
                            Layout.fillWidth: true
                            model: shadersettings.fonts_list
                            currentIndex: shadersettings.font_index
                            onCurrentIndexChanged: shadersettings.font_index = currentIndex
                        }
                        Text{text: qsTr("Font scaling:")}
                        SpinBox{
                            Layout.fillWidth: true
                            decimals: 1
                            stepSize: 0.1
                            value: shadersettings.font_scaling
                            minimumValue: 0.5
                            maximumValue: 1.5
                            onValueChanged: shadersettings.font_scaling = value;
                        }
                        Item{Layout.fillHeight: true}
                        ColorButton{
                            height: 50
                            Layout.fillWidth: true
                            Layout.columnSpan: 2
                            onButton_colorChanged: shadersettings._font_color = button_color;
                            button_color: shadersettings._font_color;
                        }
                    }
                }
                GroupBox{
                    title: qsTr("Background")
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    GridLayout{
                        anchors.fill: parent
                        columns: 2
                        Text{text: "Frame texture"}
                        ComboBox{
                            id: framescombobox
                            Layout.fillWidth: true
                            model: shadersettings.frames_list
                            currentIndex: shadersettings.frames_index
                            onCurrentIndexChanged: shadersettings.frames_index = currentIndex
                        }
                        CheckBox{
                            Layout.columnSpan: 2
                            Layout.fillWidth: true
                            checked: shadersettings.frame_reflections
                            text: qsTr("Frame reflections")
                            onCheckedChanged: shadersettings.frame_reflections = checked
                            enabled: framescombobox.model.get(framescombobox.currentIndex).reflections
                        }

                        Item{Layout.fillHeight: true}
                        ColorButton{
                            height: 50
                            Layout.fillWidth: true
                            Layout.columnSpan: 2

                            onButton_colorChanged: shadersettings._background_color= button_color
                            button_color: shadersettings._background_color;
                        }
                    }
                }
                GroupBox{
                    title: qsTr("Lights")
                    Layout.fillWidth: true
                    Layout.columnSpan: 2
                    anchors.left: parent.left
                    anchors.right: parent.right
                    GridLayout{
                        Layout.columnSpan: 2
                        columns: 2
                        rows: 2
                        anchors.left: parent.left
                        anchors.right: parent.right
                        Text{text: qsTr("Contrast")}
                        SimpleSlider{
                            onValueChanged: shadersettings.contrast = value
                            value: shadersettings.contrast
                        }
                        Text{text: qsTr("Brightness")}
                        SimpleSlider{
                            onValueChanged: shadersettings.brightness = value
                            value: shadersettings.brightness
                        }
                        //TODO decide later what to do with scaling
                        //                        SimpleSlider{
                        //                            name: "Terminal Scaling"
                        //                            onValueChanged: shadersettings.terminal_scaling = value
                        //                            value: shadersettings.terminal_scaling
                        //                        }
                        //                        SimpleSlider{
                        //                            name: "Window Scaling"
                        //                            onValueChanged: shadersettings.window_scaling = value
                        //                            value: shadersettings.window_scaling
                        //                        }
                    }
                }
                GroupBox{
                    title: qsTr("Performace")
                    Layout.fillWidth: true
                    Layout.columnSpan: 2
                    anchors.left: parent.left
                    anchors.right: parent.right
                    RowLayout{
                        Layout.columnSpan: 2
                        anchors.left: parent.left
                        anchors.right: parent.right
                        Text{text: "Animation FPS"}
                        Slider{
                            Layout.fillWidth: true
                            id: slider
                            stepSize: 1
                            maximumValue: 60
                            minimumValue: 0
                            onValueChanged: shadersettings.fps = value;
                            value: shadersettings.fps
                        }
                        Text{
                            id: textfield
                            text: slider.value
                        }
                    }
                }
            }
        }

        Tab{
            title: qsTr("Eye-candy")
            anchors.fill: parent
            anchors.margins: 15

            ColumnLayout{
                anchors.fill: parent
                GroupBox{
                    title: qsTr("Rasterization")
                    anchors.left: parent.left
                    anchors.right: parent.right
                    ColumnLayout{
                        anchors.left: parent.left
                        anchors.right: parent.right
                        RowLayout{
                            anchors.left: parent.left
                            anchors.right: parent.right
                            ExclusiveGroup { id: rasterizationgroup }
                            RadioButton {
                                text: qsTr("No Rasterization")
                                exclusiveGroup: rasterizationgroup
                                checked: shadersettings.rasterization === shadersettings.no_rasterization
                                onCheckedChanged: if(checked)
                                                      shadersettings.rasterization = shadersettings.no_rasterization
                            }
                            RadioButton {
                                text: qsTr("Scanlines")
                                exclusiveGroup: rasterizationgroup
                                checked: shadersettings.rasterization === shadersettings.scanline_rasterization
                                onCheckedChanged: if(checked)
                                                      shadersettings.rasterization = shadersettings.scanline_rasterization
                            }
                            RadioButton {
                                text: qsTr("Pixels")
                                exclusiveGroup: rasterizationgroup
                                checked: shadersettings.rasterization === shadersettings.pixel_rasterization
                                onCheckedChanged: if(checked)
                                                      shadersettings.rasterization = shadersettings.pixel_rasterization
                            }
                        }
                        SimpleSlider{
                            Layout.fillWidth: true
                            value: shadersettings.rasterization_strength
                            onValueChanged: shadersettings.rasterization_strength = value
                        }
                    }
                }
                GroupBox{
                    title: qsTr("Effects")
                    anchors.left: parent.left
                    anchors.right: parent.right
                    ColumnLayout{
                        anchors.fill: parent
                        SettingComponent{
                            name: "Bloom"
                            onValueChanged: shadersettings.bloom_strength = value
                            _value: shadersettings.bloom_strength
                        }
                        SettingComponent{
                            name: "Motion Blur"
                            onValueChanged: shadersettings.motion_blur = value
                            _value: shadersettings.motion_blur
                        }
                        SettingComponent{
                            name: "Noise"
                            onValueChanged: shadersettings.noise_strength = value
                            _value: shadersettings.noise_strength
                        }
                        SettingComponent{
                            name: "Glow"
                            onValueChanged: shadersettings.glowing_line_strength = value;
                            _value: shadersettings.glowing_line_strength
                        }
                        SettingComponent{
                            name: "Ambient light"
                            onValueChanged: shadersettings.ambient_light = value;
                            _value: shadersettings.ambient_light
                        }
                        SettingComponent{
                            name: "Screen distortion"
                            onValueChanged: shadersettings.screen_distortion = value;
                            _value: shadersettings.screen_distortion;
                        }
                        SettingComponent{
                            name: "Brightness flickering"
                            onValueChanged: shadersettings.brightness_flickering= value;
                            _value: shadersettings.brightness_flickering;
                        }
                        SettingComponent{
                            name: "Horizontal flickering"
                            onValueChanged: shadersettings.horizontal_sincronization = value;
                            _value: shadersettings.horizontal_sincronization;
                        }
                    }
                }
            }
        }
    }
}
